%This program solves for the aggregate inflation dynamics in woodford's chapter 5 model. 
%It first sets parameter values and then calls inflation. The latter does all the work.
%To see what the inputs and outputs of inflation are, look at the 
%comments at the top of that program.
%

clear all
close all

alpha=.66;%Calvo probability of not changing price
beta=.99;%discount rate
phi=1/.75;
sigv=.11;
sigf=0.25;
sigu=1;%curvature with respect to consumption...
theta=1+1/.15;
theta=70;%the markup is theta/(theta-1)
g=.18;%steady state government consumption to output ratio

%taken from woodford, page 363
delta=.012;%depreciation rate on capital
epsi=3;%curvature on capital adjustment costs (Woodford's preferred number)

tau=(theta/(theta-1))-1;%intermediate good producers are subsidized to ensure that they produce at the socially efficient level

%if labor = 1, localized labor market (in this case, the program sets sigv=0)
%if labor = 0, economy-wide labor market
labor=1;

[kap1,kap2,psi,d] = inflation(alpha,phi,beta,sigf,sigv,sigu,theta,delta,tau,epsi,g,labor);

gam=(1-alpha*beta)*(1-alpha)/alpha;

labor=0;
[kap1,kap2,psi,dd] = inflation(alpha,phi,beta,sigf,sigv,sigu,theta,delta,tau,epsi,g,labor);


sprintf(' reduced form Calvo equation: pie(t) = bet*pie(t+1) + d*mc(t)')
sprintf(' d with economy-wide factor markets = %7.4f, firm owns capital and labor market is economy-wide = %7.4f\n',gam,dd)
sprintf(' d when firm owns capital and labor markets local = %7.4f\n',d)
%pie(t) = bet*pie(t+1) + d*mc(t)
